| Title: | Access OpenDota Services in R |
|---|---|
| Description: | Provides a client for the API of OpenDota. OpenDota is a web service which is provide DOTA2 real time data. Data is collected through the Steam WebAPI. With ROpenDota you can easily grab the latest DOTA2 statistics in R programming such as latest match on official international competition, analyzing your or enemy performance to learn their strategies,etc. Please see <https://github.com/rosdyana/ROpenDota> for more information. |
| Authors: | Rosdyana Kusuma [aut, cre] |
| Maintainer: | Rosdyana Kusuma <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.2 |
| Built: | 2026-05-27 10:27:33 UTC |
| Source: | https://github.com/rosdyana/ropendota |
Count in categories for specific player id
count_in_categories(account_id)count_in_categories(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" countMe <- count_in_categories(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" countMe <- count_in_categories(account_id = id_r3m1ck) ## End(Not run)
Counting win or lose for specific player id
count_player_win_lose(account_id)count_player_win_lose(account_id)
account_id |
Steam ID |
## Not run: #Count r3m1ck's win and lose summaries id_r3m1ck = "135474549" count_win_lose <- count_player_win_lose(account_id = id_r3m1ck) ## End(Not run)## Not run: #Count r3m1ck's win and lose summaries id_r3m1ck = "135474549" count_win_lose <- count_player_win_lose(account_id = id_r3m1ck) ## End(Not run)
Get benchmark of single hero
get_hero_benchmarks(hero_id)get_hero_benchmarks(hero_id)
hero_id |
Dota2 hero id. You can get the hero id using |
GetHeroBenchmark returns a list, which includes the details like gold per minutes, xp per minutes, kills per minutes etc.
## Not run: hero_id = "47" viperBenchmarks <- get_hero_benchmarks(hero_id) ## End(Not run)## Not run: hero_id = "47" viperBenchmarks <- get_hero_benchmarks(hero_id) ## End(Not run)
Get heroes rankings for specific player id
get_hero_rankings(account_id)get_hero_rankings(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" rankings <- get_hero_rankings(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" rankings <- get_hero_rankings(account_id = id_r3m1ck) ## End(Not run)
Get hero stats
get_hero_stats()get_hero_stats()
## Not run: heroStats <- get_hero_stats() ## End(Not run)## Not run: heroStats <- get_hero_stats() ## End(Not run)
Get total status for specific player id
get_heroes()get_heroes()
## Not run: heroes <- get_heroes() ## End(Not run)## Not run: heroes <- get_heroes() ## End(Not run)
Get a list of in-game items
get_items()get_items()
get_items returns a list of in-game items, which include the columns of name, cost, secret_shop, side_shop, recipe and localized name.
## Not run: itemList <- get_items() head(itemList) ## End(Not run)## Not run: itemList <- get_items() head(itemList) ## End(Not run)
Get details of a single match
get_match_details(match_id)get_match_details(match_id)
match_id |
Dota2 match id. You can get them of a specific player using |
GetMatchDetails returns a list, which includes the details like result, duration and etc.
## Not run: match_id = "3114150257" matchDetails <- get_match_details(match_id) ## End(Not run)## Not run: match_id = "3114150257" matchDetails <- get_match_details(match_id) ## End(Not run)
Get Matches for specific player id
get_matches(account_id, limit)get_matches(account_id, limit)
account_id |
Steam ID |
limit |
matches limit |
## Not run: id_r3m1ck = "135474549" limit = 5 matches <- get_matches(account_id = id_r3m1ck, limit = limit) ## End(Not run)## Not run: id_r3m1ck = "135474549" limit = 5 matches <- get_matches(account_id = id_r3m1ck, limit = limit) ## End(Not run)
Get played heroes for specific player id
get_played_heroes(account_id)get_played_heroes(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" playedHeroes <- get_played_heroes(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" playedHeroes <- get_played_heroes(account_id = id_r3m1ck) ## End(Not run)
Get played with for specific player id
get_played_with(account_id)get_played_with(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" playedWith <- get_played_with(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" playedWith <- get_played_with(account_id = id_r3m1ck) ## End(Not run)
Get ratings for specific player id
get_player_ratings(account_id)get_player_ratings(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" ratings <- get_player_ratings(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" ratings <- get_player_ratings(account_id = id_r3m1ck) ## End(Not run)
Get Summaries a Specific Player
get_player_summaries(account_id)get_player_summaries(account_id)
account_id |
Steam ID |
## Not run: #Get r3m1ck's profile summaries id_r3m1ck = "135474549" playerSummaries <- get_player_summaries(account_id = id_r3m1ck) #Print the in-game name of r3m1ck playerSummaries$profile$personaname ## End(Not run)## Not run: #Get r3m1ck's profile summaries id_r3m1ck = "135474549" playerSummaries <- get_player_summaries(account_id = id_r3m1ck) #Print the in-game name of r3m1ck playerSummaries$profile$personaname ## End(Not run)
Get recent matches for specific player id
get_recent_matches(account_id)get_recent_matches(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" recentMatches <- get_recent_matches(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" recentMatches <- get_recent_matches(account_id = id_r3m1ck) ## End(Not run)
Get ward map for specific player id
get_wardmap(account_id)get_wardmap(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" wardMap <- get_wardmap(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" wardMap <- get_wardmap(account_id = id_r3m1ck) ## End(Not run)
Get heroes rankings for specific player id
top_player_by_hero(hero_id)top_player_by_hero(hero_id)
hero_id |
Hero Id |
## Not run: viperId = "47" topPlayer <- top_player_by_hero(hero = viperId) ## End(Not run)## Not run: viperId = "47" topPlayer <- top_player_by_hero(hero = viperId) ## End(Not run)
Get total status for specific player id
total_stats(account_id)total_stats(account_id)
account_id |
Steam ID |
## Not run: id_r3m1ck = "135474549" totalStats <- total_stats(account_id = id_r3m1ck) ## End(Not run)## Not run: id_r3m1ck = "135474549" totalStats <- total_stats(account_id = id_r3m1ck) ## End(Not run)